import {Component} from '@angular/core';
import {IonicPage, NavController, NavParams, AlertController, ToastController} from 'ionic-angular';

import {Http, Response,} from '@angular/http';

import {AppService} from '../../../service/appHttpService';
import {ActivityStatisticService} from '../../../service/activityStatisticService';
import {ReplaceApplyPage} from "../replace-apply/replace-apply";

@IonicPage()
@Component({
    selector: 'page-joinDetail',
    templateUrl: 'joinDetail.html',
})
export class JoinDetailPage {

    items: object[];

    users: object[];

    isNoSignFlag: boolean = false;


    acitivityid: string;
    acitivityName: string;

    type = '1';
    //待出行
    waitgoOrder: number;
    //待确认
    waitSureOrder: number;
    //未出行
    notgoOrder: number;
    //已出行
    hasgoOrder: number;
    //未报名
    notSign: number;

    constructor(public navCtrl: NavController,
                public navParams: NavParams,
                public alertCtrl: AlertController,
                public http: Http,
                public appService: AppService,
                public toast: ToastController,
                public activityStatisticService: ActivityStatisticService) {

    }

    ionViewDidEnter() {
        /** 订单状态   （1.待出行(已报名)、2.待确认（已报名未确认）、3.报名未出行、4.已完成  （3，4均为确认状态））*/
        this.acitivityid = this.navParams.get("id"); //活动id
        this.acitivityName = this.navParams.get("name"); //活动名称
        //初始化加载未报备
        this.items = [];

        this.activityStatisticService.activityOrderCount(this.acitivityid, (data) => {
            this.waitgoOrder = data["waitgoOrder"];
            this.waitSureOrder = data["waitSureOrder"];
            this.notgoOrder = data["notgoOrder"];
            this.hasgoOrder = data["hasgoOrder"];
        });

        this.appService.ObserverHttpGetAdd("/wisdomgroup/modules/activity/signAll/", this.acitivityid)
            .subscribe((res: Response) => {
                    let resultback = res.json();
                    this.items = resultback;
                    this.notSign = this.items.length;
                }, error => {
                    this.appService.alert('网络异常！');
                }
            );

    }


    conmon(state_value) {

        this.isNoSignFlag = true;
        this.items = [];
        this.appService.ObserverHttpPost("/wisdomgroup/modules/order/orderWaitGoWithActivityid", {
            id: this.acitivityid,
            state: state_value
        })
            .subscribe((res: Response) => {
                    let resultback = res.json();
                    this.items = resultback;
                }, error => {
                    this.appService.alert('网络异常！');
                }
            );

    }

    //报名待出行
    hasSign() {
        this.type = '2';
        this.conmon(1);
    }

    //待确认
    waitSure() {
        this.type = '3';
        this.conmon(2);
    }

    //不参加
    notJoin() {
        this.isNoSignFlag = true;
        this.type = '4';
        this.appService.ObserverHttpGet("/wisdomgroup/modules/activityNon", null)
            .subscribe((res: Response) => {
                    this.items = res.json().data;
                }, error => {
                    this.appService.alert('网络异常！');
                }
            );
    }

    //已确认未出行
    notgo() {
        this.type = '5';
        this.conmon(3);
    }

    //已确认出行
    hasgo() {
        this.type = '4';
        this.conmon(4);
    }

    //未报名
    noSign() {
        this.type = '2';
        this.items = [];
        this.isNoSignFlag = false;
        this.appService.ObserverHttpPost("/wisdomgroup/modules/activity/notSignActivityList", {activityid: this.acitivityid})
            .subscribe((res: Response) => {
                    let resultback = res.json();
                    this.items = resultback;
                }, error => {
                    this.appService.alert('网络异常！');
                }
            );
    }

    //已报名
    sign() {
        this.type = '3';
        this.items = [];
        this.isNoSignFlag = false;
        this.appService.ObserverHttpGetAdd("/wisdomgroup/modules/activity/signActivityList/", this.acitivityid)
            .subscribe((res: Response) => {
                    let resultback = res.json();
                    this.items = resultback;
                }, error => {
                    this.appService.alert('网络异常！');
                }
            );
    }

    //代报名
    goSignUp(item) {
        this.navCtrl.push('ReplaceApplyPage', {id: this.acitivityid, personInfo: item})
    }

    //不参加
    sayNo(item) {
        this.appService.ObserverHttpPostAdd("/wisdomgroup/modules/activityNon/", item.id)
            .subscribe((res: Response) => {

                }, error => {
                    this.appService.alert('网络异常！');
                }
            );
    }


}
